@@ -1,6 +1,7 @@
 from cursesplus import *
 from cursesplus import filedialog
 from cursesplus import progressbars
+from cursesplus import messagebox
 
 def __test__(stdscr):
     import random
@@ -18,7 +19,8 @@ def __test__(stdscr):
     #displaymsg(stdscr,str(cursesinput(stdscr,"HI").endswith(" ")))
     #displaymsg(stdscr,filedialog.openfilesdialog(stdscr,filter=[["*.py","Python File"],["*","All Files"]]))
     progressbars.readfile_progress_bar(stdscr,"/usr/bin/gcc")
-    progressbars.writefile_progress_bar(stdscr,"bytes.txt","".join([chr(random.randint(0,255)) for _ in range(1000000)]).encode())
+    #progressbars.writefile_progress_bar(stdscr,"bytes.txt","".join([chr(random.randint(0,255)) for _ in range(1000000)]).encode())
+    displaymsg(stdscr,[str(messagebox.askyesno(stdscr,message=["Hello","This is a question"]))])
 
 if __name__ == "__main__":
     #Testing things
